@@ -269,7 +269,7 @@ import jc.parsers.universal
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.6'
+    version = '1.7'
     description = '`lsblk` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -295,25 +295,14 @@ def _process(proc_data):
         List of Dictionaries. Structured data to conform to the schema.
     """
     for entry in proc_data:
-        # boolean changes
+        # boolean and integer changes
         bool_list = ['rm', 'ro', 'rota', 'disc_zero', 'rand']
-        for key in bool_list:
-            if key in entry:
-                try:
-                    key_bool = bool(int(entry[key]))
-                    entry[key] = key_bool
-                except (ValueError):
-                    entry[key] = None
-
-        # integer changes
         int_list = ['ra', 'alignment', 'min_io', 'opt_io', 'phy_sec', 'log_sec', 'rq_size', 'disc_aln']
-        for key in int_list:
-            if key in entry:
-                try:
-                    key_int = int(entry[key])
-                    entry[key] = key_int
-                except (ValueError):
-                    entry[key] = None
+        for key in entry:
+            if key in bool_list:
+                entry[key] = jc.utils.convert_to_bool(entry[key])
+            if key in int_list:
+                entry[key] = jc.utils.convert_to_int(entry[key])
 
     return proc_data
 
