@@ -349,11 +349,12 @@ Examples:
       }
     ]
 """
+import jc.utils
 
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.9'
+    version = '1.10'
     description = '`netstat` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -379,7 +380,7 @@ def _process(proc_data):
         List of Dictionaries. Structured data to conform to the schema.
     """
     for entry in proc_data:
-        # integer changes
+        # integer and float conversions
         int_list = ['recv_q', 'send_q', 'pid', 'refcnt', 'inode', 'unit', 'vendor', 'class',
                     'osx_flags', 'subcla', 'pcbcount', 'rcvbuf', 'sndbuf', 'rxbytes', 'txbytes',
                     'route_refs', 'use', 'mtu', 'mss', 'window', 'irtt', 'metric', 'ipkts',
@@ -387,35 +388,23 @@ def _process(proc_data):
                     'tx_ok', 'tx_err', 'tx_drp', 'tx_ovr', 'idrop', 'ibytes', 'obytes', 'r_mbuf',
                     's_mbuf', 'r_clus', 's_clus', 'r_hiwa', 's_hiwa', 'r_lowa', 's_lowa', 'r_bcnt',
                     's_bcnt', 'r_bmax', 's_bmax', 'rexmit', 'ooorcv', '0_win']
-        for key in int_list:
-            if key in entry:
-                try:
-                    key_int = int(entry[key])
-                    entry[key] = key_int
-                except (ValueError):
-                    entry[key] = None
-
-        # float changes
         float_list = ['rexmt', 'persist', 'keep', '2msl', 'delack', 'rcvtime']
-        for key in float_list:
-            if key in entry:
-                try:
-                    key_float = float(entry[key])
-                    entry[key] = key_float
-                except (ValueError):
-                    entry[key] = None
+        for key in entry:
+            if key in int_list:
+                entry[key] = jc.utils.convert_to_int(entry[key])
+            if key in float_list:
+                entry[key] = jc.utils.convert_to_float(entry[key])
 
+        # add number keys
         if 'local_port' in entry:
-            try:
-                entry['local_port_num'] = int(entry['local_port'])
-            except (ValueError):
-                pass
+            local_num = jc.utils.convert_to_int(entry['local_port'])
+            if local_num:
+                entry['local_port_num'] = local_num
 
         if 'foreign_port' in entry:
-            try:
-                entry['foreign_port_num'] = int(entry['foreign_port'])
-            except (ValueError):
-                pass
+            foreign_num = jc.utils.convert_to_int(entry['foreign_port'])
+            if foreign_num:
+                entry['foreign_port_num'] = foreign_num
 
     return proc_data
 
